from .exceptions import DhwaniAPIError
import requests
def vision_caption(client, file_path, query="describe the image", src_lang="eng_Latn", tgt_lang="kan_Knda"):
    # Build the endpoint using the client's api_base
    url = (
        f"{client.api_base}/v1/indic_visual_query"
        f"?src_lang={src_lang}&tgt_lang={tgt_lang}"
    )
    headers = {
        **client._headers(),
        "accept": "application/json"
        # Note: 'Content-Type' will be set automatically by requests when using 'files'
    }
    with open(file_path, "rb") as f:
        files = {"file": (file_path, f, "image/png")}
        data = {"query": query}
        resp = requests.post(
            url,
            headers=headers,
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

class Vision:
    @staticmethod
    def caption(*args, **kwargs):
        from . import _get_client
        return _get_client().caption(*args, **kwargs)



from .exceptions import DhwaniAPIError
import requests

def chat_create(client, prompt, src_lang, tgt_lang, **kwargs):
    url = f"{client.api_base}/v1/indic_chat"
    payload = {
        "prompt": prompt,
        "src_lang": src_lang,
        "tgt_lang": tgt_lang
    }
    payload.update(kwargs)
    resp = requests.post(
        url,
        headers={**client._headers(), "Content-Type": "application/json"},
        json=payload
    )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

class Chat:
    @staticmethod
    def create(prompt, src_lang, tgt_lang, **kwargs):
        from . import _get_client
        return _get_client().chat(prompt, src_lang, tgt_lang, **kwargs)



from .exceptions import DhwaniAPIError
import requests
def asr_transcribe(client, file_path, language):
    with open(file_path, "rb") as f:
        files = {"file": f}
        resp = requests.post(
            f"{client.api_base}/v1/transcribe/?language={language}",
            headers=client._headers(),
            files=files
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

class ASR:
    @staticmethod
    def transcribe(*args, **kwargs):
        from . import _get_client
        return _get_client().transcribe(*args, **kwargs)




import requests
from .exceptions import DhwaniAPIError

def document_ocr(client, file_path, language=None):
    """OCR a document (image/PDF) and return extracted text."""
    with open(file_path, "rb") as f:
        files = {"file": f}
        data = {}
        if language:
            data["language"] = language
        resp = requests.post(
            f"{client.api_base}/v1/document/ocr",
            headers=client._headers(),
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

def document_summarize(client, file_path, page_number=1, src_lang="eng_Latn", tgt_lang="kan_Knda"):
    """Summarize a PDF document with language and page number options."""
    url = f"{client.api_base}/v1/indic-summarize-pdf"
    headers = client._headers()
    with open(file_path, "rb") as f:
        files = {"file": (file_path, f, "application/pdf")}
        data = {
            "page_number": str(page_number),
            "src_lang": src_lang,
            "tgt_lang": tgt_lang
        }
        resp = requests.post(
            url,
            headers=headers,
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()


def extract(client, file_path, page_number, src_lang, tgt_lang):
    """
    Extract and translate text from a document (image/PDF) using query parameters.
    """
    # Build the URL with query parameters
    url = (
        f"{client.api_base}/v1/indic-extract-text/"
        f"?page_number={page_number}&src_lang={src_lang}&tgt_lang={tgt_lang}"
    )
    headers = client._headers()
    # 'requests' handles multipart/form-data automatically
    with open(file_path, "rb") as f:
        files = {"file": (file_path, f, "application/pdf")}
        resp = requests.post(
            url,
            headers=headers,
            files=files
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

def doc_query(
    client,
    file_path,
    page_number=1,
    prompt="list the key points",
    src_lang="eng_Latn",
    tgt_lang="kan_Knda"
):
    """Query a document with a custom prompt and language options."""
    url = f"{client.api_base}/v1/indic-custom-prompt-pdf"
    headers = client._headers()
    with open(file_path, "rb") as f:
        files = {"file": (file_path, f, "application/pdf")}
        data = {
            "page_number": str(page_number),
            "prompt": prompt,
            "source_language": src_lang,
            "target_language": tgt_lang
        }
        resp = requests.post(
            url,
            headers=headers,
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()


def doc_query_kannada(
    client, 
    file_path, 
    page_number=1, 
    prompt="list key points", 
    src_lang="eng_Latn",
    language=None
):
    """Summarize a document (image/PDF/text) with custom prompt and language."""
    url = f"{client.api_base}/v1/indic-custom-prompt-kannada-pdf"
    headers = client._headers()
    # 'requests' will handle multipart/form-data automatically
    with open(file_path, "rb") as f:
        files = {"file": (file_path, f, "application/pdf")}
        data = {
            "page_number": str(page_number),
            "prompt": prompt,
            "src_lang": src_lang,
        }
        if language:
            data["language"] = language
        resp = requests.post(
            url,
            headers=headers,
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()



class Documents:
    @staticmethod
    def ocr(file_path, language=None):
        from . import _get_client
        return _get_client().document_ocr(file_path, language)

    @staticmethod
    def summarize(*args, **kwargs):
        from . import _get_client
        return _get_client().document_summarize(*args, **kwargs)
    @staticmethod
    def run_extract(*args, **kwargs):
        from . import _get_client
        return _get_client().extract(*args, **kwargs)
    @staticmethod
    def run_doc_query(*args, **kwargs):
        from . import _get_client
        return _get_client().doc_query(*args, **kwargs)
    @staticmethod
    def run_doc_query_kannada(*args, **kwargs):
        from . import _get_client
        return _get_client().doc_query_kannada(*args, **kwargs)


class DhwaniAPIError(Exception):
    def __init__(self, response):
        super().__init__(f"API Error {response.status_code}: {response.text}")
        self.status_code = response.status_code
        self.response = response
